animateBackWith method

TickerFuture animateBackWith(
  1. Simulation simulation
)

Drives the animation according to the given simulation with a status of reverse.

  • simulation: The physics simulation defining motion over time.

Requires:

  • Controller must be activated by a Coral resource topology before driving motion.

Returns: A TickerFuture that completes when the simulation finishes.

Throws:

Example:

controller.animateBackWith(customSimulation);

Implementation

TickerFuture animateBackWith(Simulation simulation) =>
    _delegate.animateBackWith(simulation);