animationBehavior property
The behavior of the controller when system settings disable animations.
Implementation
final AnimationBehavior animationBehavior;
The behavior of the controller when system settings disable animations.
final AnimationBehavior animationBehavior;