broadcast property

bool broadcast
final

Whether changes to the underlying coral resource are broadcasted to multiple subscribers.

When true, uses a CoralBroadcaster to allow multiple listeners to share the same animation stream without re-activating the underlying resource. Defaults to false.

Implementation

final bool broadcast;