drive<U> method

  1. @override
Animation<U> drive<U>(
  1. Animatable<U> child
)
override

Passes this animation through an Animatable to create a transformed Animation.

Returns: A new Animation reflecting the transformed values of this controller.

Example:

final animation = controller.drive(Tween<double>(begin: 0.0, end: 100.0));

Implementation

@override
Animation<U> drive<U>(Animatable<U> child) => child.animate(this);