fling method

TickerFuture fling({
  1. double velocity = 1.0,
  2. SpringDescription? springDescription,
  3. AnimationBehavior? animationBehavior,
})

Drives the animation with a spring and initial velocity.

  • velocity: The initial velocity in units per second. Defaults to 1.0.
  • springDescription: Custom spring parameters.
  • animationBehavior: Custom animation behavior override.

Requires:

  • Controller must be activated by a Coral resource topology before driving motion.

Returns: A TickerFuture that completes when the spring simulation comes to rest.

Throws:

Example:

controller.fling(velocity: 2.0);

Implementation

TickerFuture fling({
  double velocity = 1.0,
  SpringDescription? springDescription,
  AnimationBehavior? animationBehavior,
}) =>
    _delegate.fling(
        velocity: velocity,
        springDescription: springDescription,
        animationBehavior: animationBehavior);