isActivated property

  1. @override
bool get isActivated
override

Whether the underlying animation coral resource node has been activated.

Ensures:

  • Returns true if the active engine is instantiated and running within the coral lifecycle.
  • Returns false when dormant or deactivated.

Implementation

@override
bool get isActivated => _resource.isActivated;