isCompleted property
Whether this animation is stopped at the end (status is AnimationStatus.completed).
Implementation
@override
bool get isCompleted => status.isCompleted;
Whether this animation is stopped at the end (status is AnimationStatus.completed).
@override
bool get isCompleted => status.isCompleted;