isDeactivated property

  1. @override
bool get isDeactivated
override

Whether the underlying animation coral resource node has been permanently deactivated.

Ensures:

  • Returns true if the coral resource node has terminated its lifecycle.

Implementation

@override
bool get isDeactivated => _resource.isDeactivated;