isPaused property

  1. @override
bool get isPaused
override

Whether the underlying animation coral resource node is temporarily paused.

Ensures:

  • Returns true if paused by the coral lifecycle manager.

Implementation

@override
bool get isPaused => _resource.isPaused;