lowerBound property
The value at which this animation is deemed to be dismissed.
Constraints: Must be less than or equal to upperBound.
Implementation
final double lowerBound;
The value at which this animation is deemed to be dismissed.
Constraints: Must be less than or equal to upperBound.
final double lowerBound;