stop method

void stop({
  1. bool canceled = true,
})

Stops running this animation.

  • canceled: Whether active animation futures should be completed with an exception. Defaults to true.

Ensures:

  • Stops the ticker and prevents further listener notifications until restarted.

Example:

controller.stop();

Implementation

void stop({bool canceled = true}) => _delegate.stop(canceled: canceled);