toggle method

TickerFuture toggle({
  1. double? from,
})

Toggles the direction of this animation.

If isCompleted or moving forward, runs in reverse. Otherwise runs forward.

  • from: Optional starting value.

Requires:

  • Controller must be activated by a Coral resource topology before driving motion.

Returns: A TickerFuture that completes when the animation reaches the destination bound.

Throws:

Example:

controller.toggle();

Implementation

TickerFuture toggle({double? from}) => _delegate.toggle(from: from);