upperBound property
The value at which this animation is deemed to be completed.
Constraints: Must be greater than or equal to lowerBound.
Implementation
final double upperBound;
The value at which this animation is deemed to be completed.
Constraints: Must be greater than or equal to lowerBound.
final double upperBound;