DoubleCoralElementsExtension extension

on

Properties

max Coral<double>

Available on CoralIterableElements<double>, provided by the DoubleCoralElementsExtension extension

Returns the maximum element in this collection, or throws StateError if empty.
no setter
maxOrNull Coral<double?>

Available on CoralIterableElements<double>, provided by the DoubleCoralElementsExtension extension

Returns the maximum element in this collection, or null if empty.
no setter
min Coral<double>

Available on CoralIterableElements<double>, provided by the DoubleCoralElementsExtension extension

Returns the minimum element in this collection, or throws StateError if empty.
no setter
minOrNull Coral<double?>

Available on CoralIterableElements<double>, provided by the DoubleCoralElementsExtension extension

Returns the minimum element in this collection, or null if empty.
no setter
sum Coral<double>

Available on CoralIterableElements<double>, provided by the DoubleCoralElementsExtension extension

Returns the sum of the elements in this collection.
no setter