max property
Returns the maximum element in this collection, or throws StateError if empty.
Implementation
Coral<double> get max => coral.map((source) {
if (source.isEmpty) throw StateError('No element');
return source.max;
});
Returns the maximum element in this collection, or throws StateError if empty.
Coral<double> get max => coral.map((source) {
if (source.isEmpty) throw StateError('No element');
return source.max;
});