min property
Returns the minimum element in this collection, or throws StateError if empty.
Implementation
Coral<double> get min => coral.map((source) {
if (source.isEmpty) throw StateError('No element');
return source.min;
});
Returns the minimum element in this collection, or throws StateError if empty.
Coral<double> get min => coral.map((source) {
if (source.isEmpty) throw StateError('No element');
return source.min;
});