whereNotIndexed method

Coral<List<E>> whereNotIndexed(
  1. bool test(
    1. int index,
    2. E element
    )
)

Filters elements of this collection based on an indexed predicate test reactively, returning those that do not satisfy it.

Implementation

Coral<List<E>> whereNotIndexed(bool Function(int index, E element) test) =>
    coral.map((source) => List.unmodifiable(source.whereNotIndexed(test)));