IntegerCoralElementsExtension extension

on

Properties

average Coral<double>

Available on CoralIterableElements<int>, provided by the IntegerCoralElementsExtension extension

Returns the average of the elements in this collection.
no setter
max Coral<int>

Available on CoralIterableElements<int>, provided by the IntegerCoralElementsExtension extension

Returns the maximum element in this collection, or throws StateError if empty.
no setter
maxOrNull Coral<int?>

Available on CoralIterableElements<int>, provided by the IntegerCoralElementsExtension extension

Returns the maximum element in this collection, or null if empty.
no setter
min Coral<int>

Available on CoralIterableElements<int>, provided by the IntegerCoralElementsExtension extension

Returns the minimum element in this collection, or throws StateError if empty.
no setter
minOrNull Coral<int?>

Available on CoralIterableElements<int>, provided by the IntegerCoralElementsExtension extension

Returns the minimum element in this collection, or null if empty.
no setter
sum Coral<int>

Available on CoralIterableElements<int>, provided by the IntegerCoralElementsExtension extension

Returns the sum of the elements in this collection.
no setter