ListCoralElementsExtension<E> extension

on

Methods

binarySearch(E element, int compare(E a, E b)) Coral<int>

Available on CoralListElements<E>, provided by the ListCoralElementsExtension extension

Returns the index of element in this sorted list.
binarySearchBy<K extends Comparable>(E element, K keyOf(E element), [int start = 0, int? end]) Coral<int>

Available on CoralListElements<E>, provided by the ListCoralElementsExtension extension

Returns the index of element in this sorted list.
binarySearchByCompare<K>(E element, K keyOf(E element), int compare(K a, K b), [int start = 0, int? end]) Coral<int>

Available on CoralListElements<E>, provided by the ListCoralElementsExtension extension

Returns the index of element in this sorted list.
elementAtOrNull(int index) Coral<E?>

Available on CoralListElements<E>, provided by the ListCoralElementsExtension extension

Returns the indexth element reactively, or null if out of range.
equals(List<E> other, [Equality<E> equality = const DefaultEquality()]) Coral<bool>

Available on CoralListElements<E>, provided by the ListCoralElementsExtension extension

Whether other has the same elements as this list.
lowerBound(E element, int compare(E a, E b)) Coral<int>

Available on CoralListElements<E>, provided by the ListCoralElementsExtension extension

Returns the index where element should be in this sorted list.
lowerBoundBy<K extends Comparable>(E element, K keyOf(E element), [int start = 0, int? end]) Coral<int>

Available on CoralListElements<E>, provided by the ListCoralElementsExtension extension

Returns the index where element should be in this sorted list.
lowerBoundByCompare<K>(E element, K keyOf(E element), int compare(K a, K b), [int start = 0, int? end]) Coral<int>

Available on CoralListElements<E>, provided by the ListCoralElementsExtension extension

Returns the index where element should be in this sorted list.
reversedRange(int start, int end) Coral<List<E>>

Available on CoralListElements<E>, provided by the ListCoralElementsExtension extension

Returns a new list with a range of elements reversed.
shuffledRange(int start, int end, [Random? random]) Coral<List<E>>

Available on CoralListElements<E>, provided by the ListCoralElementsExtension extension

Returns a new list with a range of elements shuffled.
slice(int start, [int? end]) Coral<List<E>>

Available on CoralListElements<E>, provided by the ListCoralElementsExtension extension

Returns a sublist of this list reactively.
slices(int length) Coral<List<List<E>>>

Available on CoralListElements<E>, provided by the ListCoralElementsExtension extension

Contiguous slices of this list with the given length.
sortedBy<K extends Comparable>(K keyOf(E element), [int start = 0, int? end]) Coral<List<E>>

Available on CoralListElements<E>, provided by the ListCoralElementsExtension extension

Returns a new list containing the sorted elements of this list by keyOf.
sortedByCompare<K>(K keyOf(E element), int compare(K a, K b), [int start = 0, int? end]) Coral<List<E>>

Available on CoralListElements<E>, provided by the ListCoralElementsExtension extension

Returns a new list containing the sorted elements of this list by compare of keyOf.
sortedRange(int start, int end, int compare(E a, E b)) Coral<List<E>>

Available on CoralListElements<E>, provided by the ListCoralElementsExtension extension

Returns a new list containing a sorted range of elements from this list.
swapped(int index1, int index2) Coral<List<E>>

Available on CoralListElements<E>, provided by the ListCoralElementsExtension extension

Returns a new list with two elements swapped.