NumericCoralElementsExtension<E extends num> extension

on

Properties

average Coral<double>

Available on CoralIterableElements<E>, provided by the NumericCoralElementsExtension extension

Returns the average of the elements in this collection.
no setter
max Coral<E>

Available on CoralIterableElements<E>, provided by the NumericCoralElementsExtension extension

Returns the maximum element in this collection, or throws StateError if empty.
no setter
maxOrNull Coral<E?>

Available on CoralIterableElements<E>, provided by the NumericCoralElementsExtension extension

Returns the maximum element in this collection, or null if empty.
no setter
min Coral<E>

Available on CoralIterableElements<E>, provided by the NumericCoralElementsExtension extension

Returns the minimum element in this collection, or throws StateError if empty.
no setter
minOrNull Coral<E?>

Available on CoralIterableElements<E>, provided by the NumericCoralElementsExtension extension

Returns the minimum element in this collection, or null if empty.
no setter
sum Coral<E>

Available on CoralIterableElements<E>, provided by the NumericCoralElementsExtension extension

Returns the sum of the elements in this collection.
no setter