maxOrNull property
Coral<E?>
get
maxOrNull
Returns the maximum element in this collection, or null if empty.
Implementation
Coral<E?> get maxOrNull => coral.map((source) => source.maxOrNull as E?);
Returns the maximum element in this collection, or null if empty.
Coral<E?> get maxOrNull => coral.map((source) => source.maxOrNull as E?);