CoralProvider<T> class abstract interface

Implemented types
Implementers
Available extensions

Constructors

CoralProvider.coral(Coral<T> coral)
Creates a CoralProvider by wrapping an existing coral reactive pipeline.
factory
CoralProvider.data(T data)
Creates a static, lightweight CoralProvider holding a fixed data payload.
factory

Properties

coral Coral<T>
The underlying Coral instance managed by this provider.
no setter
hashCode int
The hash code for this object.
no setterinherited
isActivated bool
Whether the underlying coral pipeline node has been activated.
no setteroverride
isDeactivated bool
Whether the underlying coral pipeline node has been permanently deactivated.
no setteroverride
isPaused bool
Whether the underlying coral pipeline node is temporarily paused.
no setteroverride
isRunning bool
Whether the underlying coral pipeline node is currently running.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cascade<T>(Coral<T> cascade(S data), {bool eager = false}) Coral<T>

Available on CoralProvider<S>, provided by the CoralProviderComputationExtension extension

Delegates CoralComputationExtension.cascade to the underlying Coral.
distinct([bool equals(S previous, S next)?]) Coral<S>

Available on CoralProvider<S>, provided by the CoralProviderComputationExtension extension

Delegates CoralComputationExtension.distinct to the underlying Coral.
diverge<T>(Iterable<Coral<T>> cascade(S data), {bool seal = true, bool hotswap = false, bool eager = false}) Trunk<T>

Available on CoralProvider<S>, provided by the CoralProviderComputationExtension extension

Delegates CoralComputationExtension.diverge to the underlying Coral.
fallback({S onEmpty()?, S onDamage(Object error, [StackTrace? stackTrace])?}) Coral<S>

Available on CoralProvider<S>, provided by the CoralProviderComputationExtension extension

Delegates CoralComputationExtension.fallback to the underlying Coral.
fallbackEmptyToNull() Coral<S?>

Available on CoralProvider<S>, provided by the CoralProviderComputationExtension extension

Delegates CoralComputationExtension.fallbackEmptyToNull to the underlying Coral.
guard({required bool canProceed(), Object? getReasonIfCannotProceed()?}) Coral<S>

Available on CoralProvider<S>, provided by the CoralProviderComputationExtension extension

Delegates CoralComputationExtension.guard to the underlying Coral.
map<T>(T convert(S source)) Coral<T>

Available on CoralProvider<S>, provided by the CoralProviderComputationExtension extension

Delegates CoralComputationExtension.map to the underlying Coral.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBroadcaster() CoralBroadcaster<S>

Available on CoralProvider<S>, provided by the CoralProviderExtension extension

toInheritedWidget({Key? key, required Widget child}) InheritedCoralProviderWidget<T>

Available on CoralProvider<T>, provided by the CoralProviderInheritedWidgetExtension extension

Converts this CoralProvider into an InheritedCoralProviderWidget.
toString() String
A string representation of this object.
inherited
toTerminal(void onDirty()) CoralTerminal<S>

Available on CoralProvider<S>, provided by the CoralProviderExtension extension

toWidget({Key? key, Widget errorBuilder(BuildContext context, Object error, StackTrace? stackTrace)?}) CoralWidget

Available on CoralProvider<Widget>, provided by the CoralWidgetProviderExtension extension

Converts this CoralProvider into a CoralWidget.

Operators

operator ==(Object other) bool
The equality operator.
inherited