compute method

  1. @override
  2. @nonVirtual
Widget compute()
override

Performs the actual computation and returns the new value for this node based on the upstream dependencies.

Requires:

  • Every node read inside this method MUST be declared in the manifest iterable.

Implementation

@override
@nonVirtual
@pragma('vm:prefer-inline')
Widget compute() => build();