animateBackWith method
Drives the animation according to the given simulation with a status of reverse.
simulation: The physics simulation defining motion over time.
Requires:
- Controller must be activated by a Coral resource topology before driving motion.
Returns: A TickerFuture that completes when the simulation finishes.
Throws:
- StateError if invoked while in a dormant state.
Example:
controller.animateBackWith(customSimulation);
Implementation
TickerFuture animateBackWith(Simulation simulation) =>
_delegate.animateBackWith(simulation);