drive<U> method
Passes this animation through an Animatable to create a transformed Animation.
child: The Animatable transformation (e.g. Tween) to apply.
Returns: A new Animation reflecting the transformed values of this controller.
Example:
final animation = controller.drive(Tween<double>(begin: 0.0, end: 100.0));
Implementation
@override
Animation<U> drive<U>(Animatable<U> child) => child.animate(this);