repeat method
Starts running this animation in the forward direction, and restarts when complete.
min: Minimum value during repetition. Defaults to lowerBound.max: Maximum value during repetition. Defaults to upperBound.reverse: Whether the animation alternates direction on each pass. Defaults tofalse.period: Optional duration for each repetition pass.count: Optional maximum number of repetition cycles before stopping.
Requires:
- Controller must be activated by a Coral resource topology before driving motion.
Returns:
A TickerFuture that never completes naturally while repeating indefinitely, or completes
after count cycles.
Throws:
- StateError if invoked while in a dormant state.
Example:
controller.repeat(reverse: true);
Implementation
TickerFuture repeat({
double? min,
double? max,
bool reverse = false,
Duration? period,
int? count,
}) =>
_delegate.repeat(
min: min, max: max, reverse: reverse, period: period, count: count);