value property
The current value of the animation.
Constraints: For bounded controllers, this value is bounded by lowerBound and upperBound.
Implementation
@override
double get value => _delegate.value;
set
value
(double newValue)
Stops the animation controller and sets the current value of the animation.
newValue: The new animation progress value to set immediately.
Ensures:
- Cancels any active simulation and sets value to
newValue.
Implementation
set value(double newValue) => _delegate.value = newValue;