DoubleCoralElementsExtension extension
Properties
-
max
→ Coral<
double> -
Available on CoralIterableElements<
Returns the maximum element in this collection, or throws StateError if empty.double> , provided by the DoubleCoralElementsExtension extensionno setter -
maxOrNull
→ Coral<
double?> -
Available on CoralIterableElements<
Returns the maximum element in this collection, or null if empty.double> , provided by the DoubleCoralElementsExtension extensionno setter -
min
→ Coral<
double> -
Available on CoralIterableElements<
Returns the minimum element in this collection, or throws StateError if empty.double> , provided by the DoubleCoralElementsExtension extensionno setter -
minOrNull
→ Coral<
double?> -
Available on CoralIterableElements<
Returns the minimum element in this collection, or null if empty.double> , provided by the DoubleCoralElementsExtension extensionno setter -
sum
→ Coral<
double> -
Available on CoralIterableElements<
Returns the sum of the elements in this collection.double> , provided by the DoubleCoralElementsExtension extensionno setter