ListCoralElementsExtension<E> extension
- on
Methods
-
binarySearch(
E element, int compare(E a, E b)) → Coral< int> -
Available on CoralListElements<
Returns the index ofE> , provided by the ListCoralElementsExtension extensionelementin this sorted list. -
binarySearchBy<
K extends Comparable> (E element, K keyOf(E element), [int start = 0, int? end]) → Coral< int> -
Available on CoralListElements<
Returns the index ofE> , provided by the ListCoralElementsExtension extensionelementin this sorted list. -
binarySearchByCompare<
K> (E element, K keyOf(E element), int compare(K a, K b), [int start = 0, int? end]) → Coral< int> -
Available on CoralListElements<
Returns the index ofE> , provided by the ListCoralElementsExtension extensionelementin this sorted list. -
elementAtOrNull(
int index) → Coral< E?> -
Available on CoralListElements<
Returns theE> , provided by the ListCoralElementsExtension extensionindexth element reactively, or null if out of range. -
equals(
List< E> other, [Equality<E> equality = const DefaultEquality()]) → Coral<bool> -
Available on CoralListElements<
WhetherE> , provided by the ListCoralElementsExtension extensionotherhas the same elements as this list. -
lowerBound(
E element, int compare(E a, E b)) → Coral< int> -
Available on CoralListElements<
Returns the index whereE> , provided by the ListCoralElementsExtension extensionelementshould be in this sorted list. -
lowerBoundBy<
K extends Comparable> (E element, K keyOf(E element), [int start = 0, int? end]) → Coral< int> -
Available on CoralListElements<
Returns the index whereE> , provided by the ListCoralElementsExtension extensionelementshould be in this sorted list. -
lowerBoundByCompare<
K> (E element, K keyOf(E element), int compare(K a, K b), [int start = 0, int? end]) → Coral< int> -
Available on CoralListElements<
Returns the index whereE> , provided by the ListCoralElementsExtension extensionelementshould be in this sorted list. -
reversedRange(
int start, int end) → Coral< List< E> > -
Available on CoralListElements<
Returns a new list with a range of elements reversed.E> , provided by the ListCoralElementsExtension extension -
shuffledRange(
int start, int end, [Random? random]) → Coral< List< E> > -
Available on CoralListElements<
Returns a new list with a range of elements shuffled.E> , provided by the ListCoralElementsExtension extension -
slice(
int start, [int? end]) → Coral< List< E> > -
Available on CoralListElements<
Returns a sublist of this list reactively.E> , provided by the ListCoralElementsExtension extension -
slices(
int length) → Coral< List< List< >E> > -
Available on CoralListElements<
Contiguous slices of this list with the givenE> , provided by the ListCoralElementsExtension extensionlength. -
sortedBy<
K extends Comparable> (K keyOf(E element), [int start = 0, int? end]) → Coral< List< E> > -
Available on CoralListElements<
Returns a new list containing the sorted elements of this list byE> , provided by the ListCoralElementsExtension extensionkeyOf. -
sortedByCompare<
K> (K keyOf(E element), int compare(K a, K b), [int start = 0, int? end]) → Coral< List< E> > -
Available on CoralListElements<
Returns a new list containing the sorted elements of this list byE> , provided by the ListCoralElementsExtension extensioncompareofkeyOf. -
sortedRange(
int start, int end, int compare(E a, E b)) → Coral< List< E> > -
Available on CoralListElements<
Returns a new list containing a sorted range of elements from this list.E> , provided by the ListCoralElementsExtension extension -
swapped(
int index1, int index2) → Coral< List< E> > -
Available on CoralListElements<
Returns a new list with two elements swapped.E> , provided by the ListCoralElementsExtension extension