NumericCoralElementsExtension<E extends num> extension
- on
Properties
-
average
→ Coral<
double> -
Available on CoralIterableElements<
Returns the average of the elements in this collection.E> , provided by the NumericCoralElementsExtension extensionno setter -
max
→ Coral<
E> -
Available on CoralIterableElements<
Returns the maximum element in this collection, or throws StateError if empty.E> , provided by the NumericCoralElementsExtension extensionno setter -
maxOrNull
→ Coral<
E?> -
Available on CoralIterableElements<
Returns the maximum element in this collection, or null if empty.E> , provided by the NumericCoralElementsExtension extensionno setter -
min
→ Coral<
E> -
Available on CoralIterableElements<
Returns the minimum element in this collection, or throws StateError if empty.E> , provided by the NumericCoralElementsExtension extensionno setter -
minOrNull
→ Coral<
E?> -
Available on CoralIterableElements<
Returns the minimum element in this collection, or null if empty.E> , provided by the NumericCoralElementsExtension extensionno setter -
sum
→ Coral<
E> -
Available on CoralIterableElements<
Returns the sum of the elements in this collection.E> , provided by the NumericCoralElementsExtension extensionno setter