compute method

  1. @override
  2. @nonVirtual
Widget compute()
override

Performs the actual computation and returns the new value for this node based on the single upstream dependency.

Requires:

  • The single node read inside this method MUST match the node returned by manifest.

Implementation

@override
@nonVirtual
@pragma('vm:prefer-inline')
Widget compute() => build();